@@ -7,10 +7,11 @@ class JsonToPOSTMiddleware:
 
     def __call__(self, request):
         request.data = None
+        _body = request.body
 
         if request.method == "POST" and not request.FILES:
             try:
-                request.data = json.loads(request.body)
+                request.data = json.loads(_body)
                 if csrf_token := request.data.get("csrfmiddlewaretoken"):
                     request.POST = request.POST.copy()
                     request.POST["csrfmiddlewaretoken"] = csrf_token
